@@ -20,6 +20,7 @@ import time
 import unicodedata
 import xml.etree.ElementTree
 from enum import Enum
+from pathlib import Path
 
 import requests
 
@@ -72,8 +73,9 @@ class FileHash:
         return hash_algorithm.hexdigest()
 
 
-def strtobool(val):
-    """Convert a string representation of truth to true (1) or false (0).
+def strtobool(val) -> bool:
+    """
+    Convert a string representation of truth to true (1) or false (0).
 
     True values are 'y', 'yes', 't', 'true', 'on', and '1'; false values
     are 'n', 'no', 'f', 'false', 'off', and '0'.  Raises ValueError if
@@ -176,6 +178,40 @@ class Sha512FixityCallBack:
         return "SHA512", sha(full_path)
 
 
+class ReportProgressConsoleCallback:
+
+    def __init__(self, prefix='Progress:', suffix='', length=100, fill='█', printEnd="\r"):
+        self.prefix = prefix
+        self.suffix = suffix
+        self.length = length
+        self.fill = fill
+        self.printEnd = printEnd
+        self._lock = threading.Lock()
+        self.print_progress_bar(0)
+
+    def __call__(self, value):
+        with self._lock:
+            values = value.split(":")
+            self.total = int(values[1])
+            self.current = int(values[0])
+            if self.total == 0:
+                percentage = 100.0
+            else:
+                percentage = (self.current / self.total) * 100
+            self.print_progress_bar(percentage)
+            if int(percentage) == int(100):
+                self.print_progress_bar(100.0)
+                sys.stdout.write(self.printEnd)
+                sys.stdout.flush()
+
+    def print_progress_bar(self, percentage):
+        filled_length = int(self.length * (percentage / 100.0))
+        bar_sym = self.fill * filled_length + '-' * (self.length - filled_length)
+        sys.stdout.write(
+            '\r%s |%s| (%.2f%%) %s ' % (self.prefix, bar_sym, percentage, self.suffix))
+        sys.stdout.flush()
+
+
 class UploadProgressConsoleCallback:
 
     def __init__(self, filename: str, prefix='Progress:', suffix='', length=100, fill='█', printEnd="\r"):
@@ -185,19 +221,19 @@ class UploadProgressConsoleCallback:
         self.fill = fill
         self.printEnd = printEnd
         self._filename = filename
-        self._size = float(os.path.getsize(filename))
+        self._size = float(Path(filename).stat().st_size)
         self._seen_so_far = 0
         self.start = time.time()
         self._lock = threading.Lock()
-        self.printProgressBar(0, 0)
+        self.print_progress_bar(0, 0)
 
     def __call__(self, bytes_amount):
         with self._lock:
             seconds = time.time() - self.start
             if seconds == 0:
-                seconds = 1
+                seconds = 1.0
             self._seen_so_far += bytes_amount
-            percentage = (self._seen_so_far / self._size) * 100
+            percentage = (self._seen_so_far / self._size) * float(100.0)
             rate = (self._seen_so_far / (1024 * 1024)) / seconds
             self.print_progress_bar(percentage, rate)
             if int(self._seen_so_far) == int(self._size):
@@ -246,6 +282,40 @@ class EntityType(Enum):
     CONTENT_OBJECT = "CO"
 
 
+class HTTPException(Exception):
+    """
+     Custom Exception non 404 errors
+     """
+
+    def __init__(self, reference, http_status_code, url, method_name, message):
+        self.reference = reference
+        self.url = url
+        self.method_name = method_name
+        self.http_status_code = http_status_code
+        self.msg = message
+        Exception.__init__(self, self.reference, self.http_status_code, self.url, self.msg)
+
+    def __str__(self):
+        return f"Calling method {self.method_name}() {self.url} returned HTTP {self.http_status_code}. {self.msg}"
+
+
+class ReferenceNotFoundException(Exception):
+    """
+    Custom Exception for failed lookups by reference 404 Errors
+    """
+
+    def __init__(self, reference, http_status_code, url, method_name):
+        self.reference = reference
+        self.url = url
+        self.method_name = method_name
+        self.http_status_code = http_status_code
+        self.msg = f"The requested reference {self.reference} is not found in the repository"
+        Exception.__init__(self, self.reference, self.http_status_code, self.url, self.msg)
+
+    def __str__(self):
+        return f"Calling method {self.method_name}() {self.url} returned HTTP {self.http_status_code}. {self.msg}"
+
+
 class Relationship:
     DCMI_hasFormat = "http://purl.org/dc/terms/hasFormat"
     DCMI_isFormatOf = "http://purl.org/dc/terms/isFormatOf"
@@ -335,8 +405,8 @@ class Generation:
      """
 
     def __init__(self, original: bool, active: bool, format_group: str, effective_date: str, bitstreams: list):
-        self.original = original
-        self.active = active
+        self.original = bool(original)
+        self.active = bool(active)
         self.content_object = None
         self.format_group = format_group
         self.effective_date = effective_date
@@ -465,7 +535,7 @@ class Thumbnail(Enum):
     LARGE = "large"
 
 
-def sanitize(filename):
+def sanitize(filename) -> str:
     """
     Return a fairly safe version of the filename.
 
@@ -515,10 +585,10 @@ def sanitize(filename):
 
 class AuthenticatedAPI:
     """
-    Base class for authenticated calls which need an access token
+    Base class for authenticated calls which need access token
     """
 
-    def __find_user_roles_(self):
+    def __find_user_roles_(self) -> list:
         """
         Get a list of roles for the user
         :return list of roles:
@@ -568,7 +638,7 @@ class AuthenticatedAPI:
             logger.error(f'security_tags failed {request.status_code}')
             raise RuntimeError(request.status_code, "security_tags failed")
 
-    def entity_from_string(self, xml_data: str):
+    def entity_from_string(self, xml_data: str) -> dict:
         entity_response = xml.etree.ElementTree.fromstring(xml_data)
         reference = entity_response.find(f'.//{{{self.xip_ns}}}Ref')
         title = entity_response.find(f'.//{{{self.xip_ns}}}Title')
